| Title: | Dynamic Plots for Time Series Forecasting |
|---|---|
| Description: | Combines a forecast of a time series, using the function forecast(), with the dynamic plots from dygraphs. |
| Authors: | David Beiner |
| Maintainer: | David Beiner <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 0.2 |
| Built: | 2026-06-01 09:10:55 UTC |
| Source: | https://github.com/cran/ZRA |
This plot-Method will plot the original Time Series and the predicted Data, using dygraphs.
## S3 method for class 'ZRA' plot(x,zero, ...)## S3 method for class 'ZRA' plot(x,zero, ...)
x |
(ZRA) An ZRA-Object. |
zero |
(boolean) If zero=TRUE, they will be the 0 included in the Graph. |
... |
further arguments passed to the plot method. |
This print-Method will print out the original Time Series and the predicted Data.
## S3 method for class 'ZRA' print(x, ...)## S3 method for class 'ZRA' print(x, ...)
x |
(ZRA) An ZRA-Object. |
... |
further arguments passed to the print method. |
Dynamic Plots for Time Series Forecasting
ZRA(data, FP = 10, SL = c(0.8, 0.95), ...)ZRA(data, FP = 10, SL = c(0.8, 0.95), ...)
data |
(ts) Time series data. |
FP |
(numeric) Forecast period. |
SL |
(numeric) significance levels. |
... |
further arguments passed to the forecast-function. |
An Object of class "ZRA".
forecast, dygraphs
zra <- ZRA(fdeaths) plot(zra, zero = TRUE)zra <- ZRA(fdeaths) plot(zra, zero = TRUE)